#[repr(transparent)]pub struct RemoteRoom {
inner: TypedObjectRef<RemoteRoom, <RemoteRoom as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A Room that can only be updated by making remote calls, i.e. it won’t be updated via sync.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<RemoteRoom, <RemoteRoom as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl RemoteRoom
impl RemoteRoom
Sourcepub fn name(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn name(&self) -> <RefCell<Option<String>> as Property>::Value
The name that is set for this room.
This can be empty, the display name should be used instead in the interface.
Sourcepub fn topic_linkified(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn topic_linkified(&self) -> <RefCell<Option<String>> as Property>::Value
The linkified topic of this room.
This is the string that should be used in the interface when markup is allowed.
Sourcepub fn joined_members_count(&self) -> <Cell<u32> as Property>::Value
pub fn joined_members_count(&self) -> <Cell<u32> as Property>::Value
The number of joined members in the room.
Sourcepub fn room_list_info(&self) -> <RoomListRoomInfo as Property>::Value
pub fn room_list_info(&self) -> <RoomListRoomInfo as Property>::Value
The information about this room in the room list.
Sourcepub fn loading_state(&self) -> <Cell<LoadingState> as Property>::Value
pub fn loading_state(&self) -> <Cell<LoadingState> as Property>::Value
The loading state.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the name property
Sourcepub fn connect_topic_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_topic_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the topic property
Sourcepub fn connect_topic_linkified_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_topic_linkified_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the topic-linkified property
Sourcepub fn connect_joined_members_count_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_joined_members_count_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the joined-members-count property
Sourcepub fn connect_can_knock_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_can_knock_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the can-knock property
Sourcepub fn connect_room_list_info_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_room_list_info_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the room-list-info property
Sourcepub fn connect_loading_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_loading_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the loading-state property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_name(&self)
pub fn notify_name(&self)
Notify listeners of a change in the name property
Sourcepub fn notify_topic(&self)
pub fn notify_topic(&self)
Notify listeners of a change in the topic property
Sourcepub fn notify_topic_linkified(&self)
pub fn notify_topic_linkified(&self)
Notify listeners of a change in the topic-linkified property
Sourcepub fn notify_joined_members_count(&self)
pub fn notify_joined_members_count(&self)
Notify listeners of a change in the joined-members-count property
Sourcepub fn notify_can_knock(&self)
pub fn notify_can_knock(&self)
Notify listeners of a change in the can-knock property
Sourcepub fn notify_room_list_info(&self)
pub fn notify_room_list_info(&self)
Notify listeners of a change in the room-list-info property
Sourcepub fn notify_loading_state(&self)
pub fn notify_loading_state(&self)
Notify listeners of a change in the loading-state property
Sourceimpl RemoteRoom
impl RemoteRoom
Sourcefn without_data(session: &Session, uri: MatrixRoomIdUri) -> Self
fn without_data(session: &Session, uri: MatrixRoomIdUri) -> Self
Construct a new RemoteRoom for the given URI, without any data.
Sourcepub(super) fn new(session: &Session, uri: MatrixRoomIdUri) -> Self
pub(super) fn new(session: &Session, uri: MatrixRoomIdUri) -> Self
Construct a new RemoteRoom for the given URI.
This method automatically makes a request to load the room’s data.
Sourcepub(crate) fn with_data(
session: &Session,
uri: MatrixRoomIdUri,
data: impl Into<RoomSummary>,
) -> Self
pub(crate) fn with_data( session: &Session, uri: MatrixRoomIdUri, data: impl Into<RoomSummary>, ) -> Self
Construct a new RemoteRoom for the given URI and data.
Sourcepub(crate) fn uri(&self) -> &MatrixRoomIdUri
pub(crate) fn uri(&self) -> &MatrixRoomIdUri
The Matrix URI of this room.
Sourcepub(crate) fn canonical_alias(&self) -> Option<OwnedRoomAliasId>
pub(crate) fn canonical_alias(&self) -> Option<OwnedRoomAliasId>
The canonical alias of this room.
Sourcepub(super) fn load_data_if_stale(&self)
pub(super) fn load_data_if_stale(&self)
Load the data of this room if it is considered to be stale.